@@ -1,11 +1,13 @@
 from .live_field import LiveField  # noqa
 from .live_manager import LiveManager  # noqa
+from .live_model import LiveModel  # noqa
 from .live_queryset import LiveQuerySet  # noqa
 
 
 __all__ = (
     'LiveField',
     'LiveManager',
+    'LiveModel',
     'LiveQuerySet',
 )
 
